@@ -12,7 +12,7 @@ __all__ = [
 
 class VertexFilter(object):
 
-    __module__ = 'compas.datastructures._mixins'
+    __module__ = 'compas.datastructures'
 
     def vertices_where(self, conditions, data=False):
         """Get vertices for which a certain condition or set of conditions is true.
@@ -149,7 +149,7 @@ class VertexFilter(object):
 
 class EdgeFilter(object):
 
-    __module__ = 'compas.datastructures._mixins'
+    __module__ = 'compas.datastructures'
 
     def edges_where(self, conditions, data=False):
         """Get edges for which a certain condition or set of conditions is true.
@@ -285,7 +285,7 @@ class EdgeFilter(object):
 
 class FaceFilter(object):
 
-    __module__ = 'compas.datastructures._mixins'
+    __module__ = 'compas.datastructures'
 
     def faces_where(self, conditions, data=False):
         """Get faces for which a certain condition or set of conditions is true.
