@@ -7,6 +7,10 @@ from math import pi
 from copy import deepcopy
 
 from compas.geometry import centroid_points
+from compas.geometry import offset_polygon
+
+from compas.utilities import iterable_like
+from compas.utilities import pairwise
 
 from compas.datastructures.mesh._mesh import Mesh
 from compas.datastructures.mesh.operations import mesh_split_edge
@@ -19,6 +23,7 @@ __all__ = [
     'mesh_subdivide_quad',
     'mesh_subdivide_catmullclark',
     'mesh_subdivide_doosabin',
+    'mesh_subdivide_frames',
     'trimesh_subdivide_loop',
 ]
 
@@ -77,7 +82,6 @@ class SubdMesh(Mesh):
         del self.face[fkey]
         return w
 
-
 # distinguish between subd of meshes with and without boundary
 # closed vs. open
 # pay attention to extraordinary points
@@ -141,6 +145,20 @@ def mesh_subdivide_tri(mesh, k=1):
     Mesh
         A new subdivided mesh.
 
+    Examples
+    --------
+    >>> box = Box.from_corner_corner_height([0.0, 0.0, 0.0], [1.0, 1.0, 0.0], 1.0)
+    >>> mesh = Mesh.from_shape(box)
+    >>> k = 2
+    >>> subd = mesh_subdivide_tri(mesh, k=k)
+    >>> mesh is subd
+    False
+    >>> type(mesh) is type(subd)
+    True
+    >>> k1 = sum(len(mesh.face_vertices(fkey)) for fkey in mesh.faces())
+    >>> subd.number_of_faces() == (k1 if k == 1 else k1 * 3 ** (k - 1))
+    True
+
     """
     cls = type(mesh)
     subd = mesh_fast_copy(mesh)
@@ -152,6 +170,36 @@ def mesh_subdivide_tri(mesh, k=1):
 
 def mesh_subdivide_quad(mesh, k=1):
     """Subdivide a mesh such that all faces are quads.
+
+    Parameters
+    ----------
+    mesh : Mesh
+        The mesh object that will be subdivided.
+    k : int
+        Optional. The number of levels of subdivision. Default is ``1``.
+
+    Returns
+    -------
+    Mesh
+        A new subdivided mesh.
+
+    Notes
+    -----
+
+
+    Examples
+    --------
+    >>> box = Box.from_corner_corner_height([0.0, 0.0, 0.0], [1.0, 1.0, 0.0], 1.0)
+    >>> mesh = Mesh.from_shape(box)
+    >>> k = 2
+    >>> subd = mesh_subdivide_quad(mesh, k=k)
+    >>> mesh is subd
+    False
+    >>> type(mesh) is type(subd)
+    True
+    >>> subd.number_of_faces() == mesh.number_of_faces() * 4 ** k
+    True
+
     """
     cls = type(mesh)
     for _ in range(k):
@@ -203,6 +251,7 @@ def mesh_subdivide_corner(mesh, k=1):
     cls = type(mesh)
     for _ in range(k):
         subd = mesh_fast_copy(mesh)
+
         # split every edge
         for u, v in list(subd.edges()):
             mesh_split_edge(subd, u, v, allow_boundary=True)
@@ -249,7 +298,16 @@ def mesh_subdivide_catmullclark(mesh, k=1, fixed=None):
 
     Examples
     --------
-    >>>
+    >>> box = Box.from_corner_corner_height([0.0, 0.0, 0.0], [1.0, 1.0, 0.0], 1.0)
+    >>> mesh = Mesh.from_shape(box)
+    >>> k = 2
+    >>> subd = mesh_subdivide_catmullclark(mesh, k=k)
+    >>> mesh is subd
+    False
+    >>> type(mesh) is type(subd)
+    True
+    >>> subd.number_of_faces() == mesh.number_of_faces() * 4 ** k
+    True
 
     """
     cls = type(mesh)
@@ -383,6 +441,17 @@ def mesh_subdivide_doosabin(mesh, k=1, fixed=None):
     Mesh
         A new subdivided mesh.
 
+    Examples
+    --------
+    >>> box = Box.from_corner_corner_height([0.0, 0.0, 0.0], [1.0, 1.0, 0.0], 1.0)
+    >>> mesh = Mesh.from_shape(box)
+    >>> k = 2
+    >>> subd = mesh_subdivide_doosabin(mesh, k=k)
+    >>> mesh is subd
+    False
+    >>> type(mesh) is type(subd)
+    True
+
     """
     if not fixed:
         fixed = []
@@ -420,7 +489,6 @@ def mesh_subdivide_doosabin(mesh, k=1, fixed=None):
                     cy += alpha * y
                     cz += alpha * z
 
-                # fkey_old_new[fkey][old] = subd.add_vertex(x=cx, y=cy, z=cz)
                 new = subd.add_vertex(cx, cy, cz)
                 fkey_old_new[fkey][old] = new
 
@@ -428,9 +496,6 @@ def mesh_subdivide_doosabin(mesh, k=1, fixed=None):
 
             subd.add_face(face)
 
-        # for fkey in mesh.faces():
-        #     subd.add_face([fkey_old_new[fkey][key] for key in mesh.face_vertices(fkey)])
-
         boundary = set(mesh.vertices_on_boundary())
 
         for key in mesh.vertices():
@@ -472,6 +537,75 @@ def mesh_subdivide_doosabin(mesh, k=1, fixed=None):
     return subd2
 
 
+def mesh_subdivide_frames(mesh, offset, add_windows=False):
+    """Subdivide a mesh by creating offset frames and windows on its faces.
+
+    Parameters
+    ----------
+    mesh : Mesh
+        The mesh object to be subdivided.
+    offset : float or dict
+        The offset distance to create the frames.
+        A single value will result in a constant offset everywhere.
+        A dictionary mapping facekey: offset will be processed accordingly.
+    add_windows : boolean
+        Optional. Flag to add window face. Default is ``False``.
+
+    Returns
+    -------
+    Mesh
+        A new subdivided mesh.
+
+    Examples
+    --------
+    >>>
+
+    """
+
+    subd = SubdMesh()
+
+    # 0. pre-compute offset distances
+    if not isinstance(offset, dict):
+        distances = iterable_like(mesh.faces(), [offset], offset)
+        offset = {fkey: od for fkey, od in zip(mesh.faces(), distances)}
+
+    # 1. add vertices
+    newkeys = {}
+    for vkey, attr in mesh.vertices(True):
+        newkeys[vkey] = subd.add_vertex(*mesh.vertex_coordinates(vkey))
+
+    # 2. add faces
+    for fkey in mesh.faces():
+        face = [newkeys[vkey] for vkey in mesh.face_vertices(fkey)]
+        d = offset.get(fkey)
+
+        # 2a. add face and break if no offset is found
+        if d is None:
+            subd.add_face(face)
+            continue
+
+        polygon = offset_polygon(mesh.face_coordinates(fkey), d)
+
+        # 2a. add offset vertices
+        window = []
+        for xyz in polygon:
+            x, y, z = xyz
+            new_vkey = subd.add_vertex(x=x, y=y, z=z)
+            window.append(new_vkey)
+
+        # 2b. frame faces
+        face = face + face[:1]
+        window = window + window[:1]
+        for sa, sb in zip(pairwise(face), pairwise(window)):
+            subd.add_face([sa[0], sa[1], sb[1], sb[0]])
+
+        # 2c. window face
+        if add_windows:
+            subd.add_face(window)
+
+    return subd
+
+
 def trimesh_subdivide_loop(mesh, k=1, fixed=None):
     """Subdivide a triangle mesh using the Loop algorithm.
 
@@ -491,25 +625,23 @@ def trimesh_subdivide_loop(mesh, k=1, fixed=None):
 
     Examples
     --------
-    .. code-block:: python
+    Make a low poly mesh from a box shape.
+    Triangulate the faces.
+    >>> box = Box.from_corner_corner_height([0.0, 0.0, 0.0], [1.0, 1.0, 0.0], 1.0)
+    >>> mesh = Mesh.from_shape(box)
+    >>> mesh_quads_to_triangles(mesh)
 
-        from compas.datastructures import Mesh
-        from compas.datastructures import mesh_flip_cycle_directions
-        from compas_plotters import SubdMeshViewer
+    Subdivide 2 times.
+    >>> k = 2
+    >>> subd = trimesh_subdivide_loop(mesh, k=k)
 
-        mesh = Mesh.from_polyhedron(4)
-        mesh_flip_cycle_directions(mesh)
-
-        viewer = SubdMeshViewer(mesh, subdfunc=loop_subdivision, width=600, height=600)
-
-        viewer.axes_on = False
-        viewer.grid_on = False
-
-        for _ in range(10):
-            viewer.camera.zoom_in()
-
-        viewer.setup()
-        viewer.show()
+    Compare low-poly cage with subdivision mesh.
+    >>> mesh is subd
+    False
+    >>> type(mesh) is type(subd)
+    True
+    >>> subd.number_of_faces() == mesh.number_of_faces() * (3 + 1) ** k
+    True
 
     """
     cls = type(mesh)
@@ -617,27 +749,32 @@ def trimesh_subdivide_loop(mesh, k=1, fixed=None):
 
 if __name__ == "__main__":
 
-    import compas
+    import doctest
+    import compas  # noqa: F401
     from compas.datastructures import Mesh
-    from compas.geometry import Box
+    from compas.datastructures import mesh_quads_to_triangles  # noqa: F401
+    from compas.geometry import Box  # noqa: F401
+
     # from compas_plotters import MeshPlotter
-    from compas_viewers.meshviewer import MeshViewer
-    from compas.utilities import print_profile
+    # from compas_viewers.meshviewer import MeshViewer
+    # from compas.utilities import print_profile
 
-    mesh = Mesh.from_obj(compas.get('faces.obj'))
-    mesh = Mesh.from_shape(Box.from_corner_corner_height((0.0, 0.0, 0.0), (1.0, 1.0, 0.0), 1.0))
+    # mesh = Mesh.from_obj(compas.get('faces.obj'))
+    # mesh = Mesh.from_shape(Box.from_corner_corner_height((0.0, 0.0, 0.0), (1.0, 1.0, 0.0), 1.0))
 
-    subdivide = print_profile(mesh_subdivide_tri)
-    # subdivide = print_profile(mesh_subdivide_quad)
-    # subdivide = print_profile(mesh_subdivide_catmullclark)
-    # subdivide = print_profile(mesh_subdivide_corner)
-    # subdivide = print_profile(mesh_subdivide_doosabin)
+    # subdivide = print_profile(mesh_subdivide_tri)
+    # # subdivide = print_profile(mesh_subdivide_quad)
+    # # subdivide = print_profile(mesh_subdivide_catmullclark)
+    # # subdivide = print_profile(mesh_subdivide_corner)
+    # # subdivide = print_profile(mesh_subdivide_doosabin)
 
-    subd = subdivide(mesh, k=6)
+    # subd = subdivide(mesh, k=6)
 
-    print(subd.number_of_faces())
+    # print(subd.number_of_faces())
 
-    viewer = MeshViewer()
-    viewer.mesh = subd
+    # viewer = MeshViewer()
+    # viewer.mesh = subd
 
-    viewer.show()
+    # viewer.show()
+
+    doctest.testmod(globs=globals())
