@@ -2,6 +2,6 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-from .volmesh import *
+from .volmesh import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
