@@ -3,7 +3,7 @@ from __future__ import division
 from __future__ import print_function
 
 
-from .planarisation import *
+from .planarisation import *  # noqa: F401 F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
