@@ -4,10 +4,8 @@ import math
 
 from compas.geometry.basic import cross_vectors
 from compas.geometry.basic import subtract_vectors
-from compas.geometry.basic import allclose
 
 from compas.geometry.transformations import Transformation
-from compas.geometry.transformations import Rotation
 
 from compas.geometry.transformations import matrix_from_basis_vectors
 from compas.geometry.transformations import basis_vectors_from_matrix
@@ -18,13 +16,10 @@ from compas.geometry.transformations import matrix_from_axis_angle_vector
 from compas.geometry.transformations import euler_angles_from_matrix
 from compas.geometry.transformations import matrix_from_euler_angles
 from compas.geometry.transformations import decompose_matrix
-from compas.geometry.transformations import matrix_inverse
-from compas.geometry.transformations import matrix_from_frame
 
 from compas.geometry.primitives import Primitive
 from compas.geometry.primitives import Point
 from compas.geometry.primitives import Vector
-from compas.geometry.primitives import Plane
 from compas.geometry.primitives import Quaternion
 
 __all__ = ['Frame']
@@ -508,17 +503,6 @@ class Frame(Primitive):
         self.xaxis = data['xaxis']
         self.yaxis = data['yaxis']
 
-    def to_data(self):
-        """Returns the data dictionary that represents the frame.
-
-        Returns
-        -------
-        dict
-            The frame data.
-
-        """
-        return self.data
-
     @property
     def normal(self):
         """:class:`Vector` : The frame's normal (z-axis)."""
