@@ -1,8 +1,3 @@
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from compas_blender.utilities import delete_objects
 from compas_blender.utilities import get_objects
 
@@ -26,10 +21,6 @@ __all__ = [
 ]
 
 
-def redraw():
-    bpy.ops.wm.redraw_timer(type='DRAW_WIN_SWAP', iterations=1)
-
-
 # ==============================================================================
 # create
 # ==============================================================================
@@ -83,7 +74,7 @@ def clear_current_layer():
 def delete_layer(layer):
     collection = bpy.data.collections[layer]
     bpy.context.scene.collection.children.unlink(collection)
-    redraw()
+    # redraw()
     collection = bpy.data.collections[layer]
     bpy.data.collections.remove(collection)
 
@@ -99,6 +90,4 @@ def delete_layers(layers):
 
 if __name__ == "__main__":
 
-    clear_layer(layer='Collection 1')
-
-    print(list(bpy.data.collections))
+    pass
