@@ -62,6 +62,7 @@ def xtransform(geo, transformation):
     T = xform_from_transformation(transformation)
     geo.Transform(T)
 
+
 def xtransformed(geo, transformation):
     """Returns a copy of the transformed Rhino Geometry object.
 
@@ -75,4 +76,12 @@ def xtransformed(geo, transformation):
     T = xform_from_transformation(transformation)
     geo_copy = geo.Duplicate()
     geo_copy.Transform(T)
-    return geo_copy
\ No newline at end of file
+    return geo_copy
+
+
+# ==============================================================================
+# Main
+# ==============================================================================
+
+if __name__ == '__main__':
+    pass
