@@ -8,6 +8,6 @@ compas_ghpython.helpers
 """
 from __future__ import absolute_import
 
-from .mesh import *
+from .mesh import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
